@@ -14,8 +14,8 @@ import requests
 from dateutil.parser import parse
 import base64
 from .mobio_admin_sdk import MobioAdminSDK
-
-# from mobio.libs.ciphers import MobioCrypt2
+from .aes_cipher import CryptUtil
+from mobio.libs.ciphers import MobioCrypt2
 import json
 from flask import request
 from .aes_cipher import AESCipher
@@ -39,7 +39,10 @@ def decrypt_data(enc_data):
 
 
 def get_merchant_auth(merchant_id):
-    result = get_info_merchant_config(merchant_id)
+    result = get_merchant_config_host(merchant_id)
+    if not result or not result.get("jwt_algorithm") or not result.get("jwt_secret_key"):
+        print("admin_sdk::get_merchant_auth: jwt_algorithm None, jwt_secret_key None")
+        raise ValueError("admin_sdk::can not get merchant config auth ")
     return {
         SystemConfigKeys.JWT_ALGORITHM: result.get("jwt_algorithm"),
         SystemConfigKeys.JWT_SECRET_KEY: result.get("jwt_secret_key"),
@@ -82,13 +85,11 @@ def get_info_merchant_config(
 
 
 def check_basic_auth(partner_key):
-    partner_info_enc = get_partner_info_by_key(partner_key)
-    if not partner_info_enc:
-        return False
     try:
-        # partner_info_dec = MobioCrypt2.d1(partner_info_enc, enc="utf-8")
-        # partner_info = json.loads(partner_info_dec)
-        partner_info = decrypt_data(partner_info_enc)
+        partner_info = get_partner_info_decrypt(partner_key, decrypt=True)
+        if not partner_info and partner_info.get("data"):
+            return False
+        # partner_info = decrypt_data(partner_info_enc)
         expire_time = parse(partner_info.get("expired_time"))
         if expire_time.replace(tzinfo=None) < datetime.datetime.utcnow():
             print("admin_sdk::check_basic_auth: reach expire time: %s" % str(expire_time))
@@ -98,12 +99,21 @@ def check_basic_auth(partner_key):
         print("admin_sdk::check_basic_auth: error: %s" % e)
         return False
 
+def get_partner_info_decrypt(partner_key, decrypt=False):
+    partner_info_enc = get_partner_info_by_key(partner_key)
+    if not decrypt:
+        return partner_info_enc
+    else:
+        if not partner_info_enc or not isinstance(partner_info_enc, dict) or not partner_info_enc.get("data"):
+            return partner_info_enc
+        partner_info_dec = MobioCrypt2.d1(partner_info_enc.get("data"), enc="utf-8")
+        return {"code": 200, "data": json.loads(partner_info_dec)}
 
 @MobioAdminSDK.lru_cache.add()
 def get_partner_info_by_key(partner_key):
     if not partner_key:
         return None
-    adm_url = str(UrlConfig.PARTNER_INFO).format(
+    adm_url = str(UrlConfig.PARTNER_INFO_CIPHER_ENCRYPT).format(
         host=MobioAdminSDK().admin_host,
         version=MobioAdminSDK().admin_version,
         partner_id=partner_key,
@@ -114,21 +124,14 @@ def get_partner_info_by_key(partner_key):
         timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
     )
     resp.raise_for_status()
-    status_code = resp.status_code
-    if status_code == 200:
-        result = resp.json()
-        enc_data = result["data"]
-        return enc_data
-    else:
-        print("admin_sdk::get_expire_time_by_key: error: status_code = %d" % status_code)
-        return None
+    return resp.json()
 
 
 def check_basic_auth_v2(partner_key):
-    partner_info_enc = get_partner_info_by_key_v2(partner_key)
-    if not partner_info_enc:
-        return False
     try:
+        partner_info_enc = get_partner_info_by_key_v2(partner_key)
+        if not partner_info_enc:
+            return False
         # partner_info_dec = MobioCrypt2.d1(partner_info_enc, enc="utf-8")
         # partner_info = json.loads(partner_info_dec)
         partner_info = decrypt_data(partner_info_enc)
@@ -442,6 +445,9 @@ def get_merchant_config_host(
     admin_version=None,
     request_timeout=MobioAdminSDK.DEFAULT_REQUEST_TIMEOUT_SECONDS,
 ):
+    if SystemConfigKeys.vm_type and not CryptUtil.license_server_valid():
+        raise ValueError("license server invalid")
+
     api_version = MobioAdminSDK().admin_version
     if admin_version and admin_version in MobioAdminSDK.LIST_VERSION_VALID:
         api_version = admin_version
@@ -589,3 +595,33 @@ def get_server_uri_default_from_module(key_module):
     server_id = key_module
     db_uri = os.environ.get(key_module)
     return server_id, db_uri
+
+@MobioAdminSDK.lru_cache.add()
+def get_list_api_register_app(merchant_id, app_id):
+    result = get_merchant_config_host(merchant_id)
+    if not result or not result.get("data-out-app-api-service-host"):
+        return None
+    api_url = "{host}/datasync/api/v1.0/api-out/app/api-register".format(
+        host=result.get("data-out-app-api-service-host")
+    )
+    params = {
+        "app_id": app_id
+    }
+    request_header = {
+        "Authorization": SystemConfigKeys.MOBIO_TOKEN,
+        "X-Merchant-Id": merchant_id
+    }
+    if MobioAdminSDK().request_header:
+        request_header.update(MobioAdminSDK().request_header)
+    response = requests.get(
+        api_url,
+        params=params,
+        headers=request_header,
+        timeout=2,
+    )
+    response.raise_for_status()
+    result = response.json()
+    if result and result.get("data"):
+        return result.get("data")
+    else:
+        return None
